import {Component, ElementRef, Input, OnChanges, OnInit, ViewChild} from '@angular/core';
import {Chart} from "chart.js/auto";

import {DatePipe} from "@angular/common";
import {LogLevel, MyLoggerServiceService} from "../../../../shared/service/my-logger-service.service";
import {SensorData} from "../../pro-view/pro-view.component";
import {ReadingPayload} from "../../../../../../projects/generated-api/src";


@Component({
  selector: 'app-Cjs-timeline-multiple',
  templateUrl: './cjsTimlineMultiple.component.html',
  styleUrls: ['./cjsTimlineMultiple.component.scss']
})
export class CjsTimelineMultiple implements OnInit,OnChanges{

  constructor(private logger:MyLoggerServiceService) {
    logger.setLevel(LogLevel.LOG)
    logger.setTopic("CjsTimlineMultiple-Child")
  }

  ngOnInit(): void {
    this.mapData();
  }

  @ViewChild('myCanvas') canvas!: ElementRef;

  @Input() chartId:String="test"
  @Input() sensorData!:SensorData[]
  @Input() sensorDataArray!:[SensorData[]]

  dataParentArray:[Number[]]=[[]]
  dataParentArrayError:ReadingPayload.SensorErrorEnum[][]=[]
  timeStampsAsHour:any

//*************************lineChart-Trio*****************************
  footer = (tooltipItems:any) => {
    let i = 0;
    let j= 0;
    tooltipItems.forEach(function(tooltipItem:any) {
      i = tooltipItem.datasetIndex;
      j = tooltipItem.dataIndex
    });
    if(this.dataParentArrayError[i+2][j]=='NO_ERROR')
      return ;
    return this.dataParentArrayError[i+2][j];
  };
  linConfig:any={
    type:'line',
    data:{datasets: [{},]},
    options:{
      responsive:true,
      radius:5,
      hoverRadius:12,
      hitRadius:30,
      tooltips: {
        mode: 'index',
        intersect: true
      },
      plugins:{
        legend: {
          display: false
        },
        tooltip: {
          callbacks: {
            footer: this.footer,
          }
        }
      }
    }
  }




  linechart: any;
   ngAfterViewInit() {
    this.linConfig.data.labels=this.timeStampsAsHour
    this.linechart = new Chart(this.chartId.toString(), this.linConfig)
  }

  ngOnChanges() {
    /**********THIS FUNCTION WILL TRIGGER WHEN PARENT COMPONENT UPDATES 'someInput'**************/
    //Map the Data from the Parent
    this.mapData()
    this.linConfig.data.labels=this.timeStampsAsHour

    //Filtering SensorLabels
    let sensorLabels: string[] = [];
    this.sensorDataArray.forEach(dat => {
      if (dat && dat[0] && dat[0].sensorName) {
        sensorLabels.push(dat[0].sensorName);
      }})
    this.logger.info("Filterd Sensor Labels",sensorLabels)
    let rgb
    const dataSet = Array.from({ length: this.sensorDataArray.length }, (_, i) => (
      {
      label:`Dataset ${i+1} `+sensorLabels.at(i),
      backgroundColor:( (rgb=getRandomColor())+'0.1)'),
      fill:true,
      borderColor:(rgb+'0.8)'),
      tension:0.2,
      data:this.dataParentArray.at(i+2),
      pointStyle: this.dataParentArrayError.at(i+2)?.map(error=>error=="NO_ERROR"?"circle":"triangle"),
      pointRadius: this.dataParentArrayError.at(i+2)?.map(error=>error=="NO_ERROR"?5:20),
      pointBackgroundColor: this.dataParentArrayError.at(i+2)?.map(error=>error=="NO_ERROR"?"rgba(0,0,0,0)":"rgba(255,0,0,0.5)"),

    }));
    this.linConfig.data.datasets=dataSet

    //update the Chart with the new Data from Paten
    if(this.linechart !== undefined)
      this.linechart.update();
    this.logger.info("Updated Chart")
  }

  mapData(){
     //Map the timeline
    let datePipe = new DatePipe('en-US');
    if(this.sensorDataArray.at(0)!=undefined)
      this.timeStampsAsHour = this.sensorDataArray.at(1)?.map(x => x.timestamp)
        ?.map(x => datePipe.transform(x, 'HH:mm'))
        ?? [];

    this.logger.info("Timeline got from Server #gS",this.timeStampsAsHour)

    //Map the SensorData
    this.dataParentArray=[[]]
    this.dataParentArrayError=[[]]
    this.sensorDataArray.forEach(
      sensDat=>{
        this.dataParentArray.push(sensDat.map(x=>x.readings.map(y=>y.value)).flat())
        this.dataParentArrayError.push(sensDat.map(x=>x.errorStatus))
      }
    )
    this.logger.info("SensorData got from Server",this.dataParentArray)
    this.logger.info("SensorDataError got from Server",this.dataParentArrayError)
    this.logger.info("Finished Mapping data")
  }
}
function getRandomColor(): string {
  const r = Math.floor(Math.random() * 256);
  const g = Math.floor(Math.random() * 256);
  const b = Math.floor(Math.random() * 256);
  return `rgba(${r}, ${g}, ${b}, `;
}


