import {Component, ElementRef, Input, OnChanges, OnInit, ViewChild} from '@angular/core';
import {Chart} from "chart.js/auto";
import {ThreePhaseDendrometer} from "../../../../../../projects/generated-api/src"
import {DatePipe} from "@angular/common";
import {LogLevel, MyLoggerServiceService} from "../../../../shared/service/my-logger-service.service";


@Component({
  selector: 'app-Cjs-timline',
  templateUrl: './cjsTimlineMultiple.component.html',
  styleUrls: ['./cjsTimlineMultiple.component.scss']
})
export class CjsTimline implements OnInit,OnChanges{

  constructor(private logger:MyLoggerServiceService) {
    logger.setLevel(LogLevel.LOG)
    logger.setTopic("CjsTimline")
  }

  ngOnInit(): void {
    this.mapData();
  }

  @ViewChild('myCanvas') canvas!: ElementRef;

  @Input() chartId:String="test"
  @Input() threePhaseDenrometer!:ThreePhaseDendrometer
  dataParent:Number[]=[]
  timeStampsAsHour:any
  coloredData:any
  colorMapper = new Map<String, String>([
    ["CONTRACTION", "#155263"],
    ["EXPANSION", "#ff6f3c"],
    ["STEM_RADIUS_INCREASE", "#ffc93c"]
  ]);

//*************************lineChart-Trio*****************************
  data:any ={
    datasets: [ {
      label: "Baum Umfang",
      data: this.dataParent,
      fill:true,
      borderColor:"rgba(152,112,112,0.8)",
      backgroundColor: "rgba(162,66,66,0.1)",
      tension:0.2,
    },
    ]
  }

  linConfig:any={
    type:'line',
    data:this.data,
    options:{
      responsive:true,
      radius:5,
      hoverRadius:12,
      hitRadius:30,
      tooltips: {
        mode: 'index',
        intersect: true
      },
      plugins:{
        legend: {
          display: false
        }
      }
    }
  }

  linechart: any;


  mapData(){
    //@ts-ignore
    this.dataParent=this.threePhaseDenrometer[0].readings.map(x=>x.value)
    this.logger.info("Values of Circumference #gS",this.dataParent)
    // @ts-ignore
    let timeStamp:Date[]=this.threePhaseDenrometer[0].readings.map(y=> y.timestamp)

    let datePipe = new DatePipe('en-US');
    this.timeStampsAsHour=timeStamp.map(x=>datePipe.transform(x,'HH:mm'))
    this.logger.info("Timeline got from Server #gS",this.timeStampsAsHour)
    // @ts-ignore
    this.coloredData=this.threePhaseDenrometer[0].readings.map(y=>this.colorMapper.get(y.fluctuationType))
    // @ts-ignore
    this.logger.info("Data Code #gS",this.coloredData);
    this.logger.info("Finished Mapping data")
  }

   ngAfterViewInit() {
    this.linConfig.data.labels=this.timeStampsAsHour
    this.linConfig.data.datasets[0].data=this.dataParent
     this.linConfig.data.datasets[0].pointBorderColor=this.coloredData
     this.linConfig.data.datasets[0].pointBackgroundColor=this.coloredData
    this.linechart = new Chart(this.chartId.toString(), this.linConfig)
  }

  ngOnChanges() {
    /**********THIS FUNCTION WILL TRIGGER WHEN PARENT COMPONENT UPDATES 'someInput'**************/
    //Write your code here
    this.mapData()
    this.linConfig.data.labels=this.timeStampsAsHour
    this.linConfig.data.datasets[0].data=this.dataParent
    this.linConfig.data.datasets[0].pointBorderColor=this.coloredData
    this.linConfig.data.datasets[0].pointBackgroundColor=this.coloredData
    this.linechart.data = this.linConfig.data;
    console.log("channnged")
    this.linechart.update();
  }

}
