import {Component} from '@angular/core';
import {FormBuilder, FormGroup} from "@angular/forms";
import {ApiService} from "../../../../../shared/api.service";
import {ClientModel} from "./client.model";

interface sensorDataType {
  sensorData: any;
  isAddedToClient: boolean;
}

@Component({
  selector: 'app-client',
  templateUrl: './client.component.html',
  styleUrls: ['./client.component.css']
})

export class ClientComponent {

  formClient!: FormGroup;
  clientData!: any;
  showAddButton!: boolean;
  showUpdateButton!: boolean;
  sensorData: sensorDataType[] = [];
  sensorIdsToBeAdded: string[] = [];

  clientModel : ClientModel = new ClientModel();
  constructor(private api: ApiService, private fb: FormBuilder) {
    this.getAllClients();
    this.getAllSensors();
    this.formClient = fb.group({
      name: [''],
      description: [''],
      mac: [''],
      connectionType: [''],
      sensors: [''],
    });
  }

  private getAllClients() {
    this.api.get('http://localhost:8080/api/v1/client/all')
      .subscribe(res => {
        this.clientData = res;
      });
  }

  onAddClient() {

    this.clientModel.name = this.formClient.value.name;
    this.clientModel.description = this.formClient.value.description;
    this.clientModel.mac = this.formClient.value.mac;
    this.clientModel.connectionType = this.formClient.value.connectionType;
    this.clientModel.sensors = this.sensorIdsToBeAdded

    this.api.post('http://localhost:8080/api/v1/client/add', this.clientModel)
      .subscribe(res => {
        this.getAllClients();
        this.formClient.reset();
        alert('Client added successfully');
        document.getElementById('cancel-btn')?.click();
      }, err => {
        alert('An error has occurred.');
      });
  }

  onOpenEditClient(row: any) {
    this.showAddButton = false;
    this.showUpdateButton = true;
  }

  onOpenAddClient() {
    this.showAddButton = true;
    this.showUpdateButton = false;
  }

  onUpdateClient() {

  }

  // @ts-ignore
 async getAllSensors() {
    await this.api.get('http://localhost:8080/api/v1/sensor/all')
      .subscribe(res => {
        res.forEach((sensor: any) => {
          this.sensorData.push({sensorData: sensor, isAddedToClient: false});
        });
      });
  }

  getSensorName(sensorId: number) {
    return this.sensorData?.find(sensor => sensor.sensorData.id === sensorId)?.sensorData.name;
  }

  onChange(target: any) {
    console.log(target.value);
  }

  onAddSensorToConfig(sensor: sensorDataType) {
    this.sensorIdsToBeAdded.push(sensor.sensorData.id);
    sensor.isAddedToClient = true;
  }

  onRemoveSensorToConfig(sensor: sensorDataType) {
    this.sensorIdsToBeAdded = this.sensorIdsToBeAdded.filter(sensorId => sensorId !== sensor.sensorData.id);
    sensor.isAddedToClient = false;
  }
}
