import {Component} from '@angular/core';
import {ApiService} from "../../../../../shared/api.service";
import {FormBuilder, FormGroup} from "@angular/forms";
import {SensorModel} from "./sensor.model";

@Component({
  selector: 'app-sensor',
  templateUrl: './sensor.component.html',
  styleUrls: ['./sensor.component.css']
})
export class SensorComponent {

  sensorForm!: FormGroup;
  sensorData!: any;

  sensor: SensorModel = new SensorModel();
  showAddButton!: boolean;
  showUpdateButton!: boolean;

  constructor(private api: ApiService, private formBuilder: FormBuilder) {
    this.getAllSensors();
    this.sensorForm = formBuilder.group({
      name: [''],
      protocol: [''],
      protocolAddress: [''],
      description: [''],
      mName: [''],
      type: [''],
      maxValue: [''],
      minValue: [''],
      unit: [''],
      comment: [''],
      precision: [''],
      maxReadoutDifference: [''],
      maxFrozenTimeInSeconds: [''],
    });
  }

  getAllSensors() {
    this.api.get('http://localhost:8080/api/v1/sensor/all')
      .subscribe(res => {
        this.sensorData = res;
      });
  }

  onAddSensor() {
    this.sensor.name = this.sensorForm.value.name;
    this.sensor.protocol = this.sensorForm.value.protocol;
    this.sensor.protocolAddress = this.sensorForm.value.protocolAddress;
    this.sensor.description = this.sensorForm.value.description;
    this.sensor.measurements = [{
      name: this.sensorForm.value.mName,
      type: this.sensorForm.value.type,
      maxValue: this.sensorForm.value.maxValue,
      minValue: this.sensorForm.value.minValue,
      unit: this.sensorForm.value.unit,
      comment: this.sensorForm.value.comment,
      precision: this.sensorForm.value.precision,
      maxReadoutDifference: this.sensorForm.value.maxReadoutDifference,
      maxFrozenTimeInSeconds: this.sensorForm.value.maxFrozenTimeInSeconds
    }];

    this.api.post('http://localhost:8080/api/v1/sensor/add', this.sensor)
      .subscribe(res => {
        alert('Sensor added successfully.');
        this.getAllSensors();
        this.sensorForm.reset();
        document.getElementById('cancel-btn')?.click();
      }, err => {
        alert('An error has occurred.');
      });
  }

  onUpdateSensor() {
  }

  onOpenAddSensor() {
    this.showAddButton = true;
    this.showUpdateButton = false;
  }

  onOpenEditSensor(row: any) {
    this.showAddButton = false;
    this.showUpdateButton = true;
  }
}
