import {Component} from '@angular/core';
import {ApiService} from "../../../../../shared/api.service";
import {FormBuilder, FormGroup} from "@angular/forms";
import {StationModel} from "./station.model";

interface clientDataType {
  clientData: any;
  isAddedToStation: boolean;
}

@Component({
  selector: 'app-station',
  templateUrl: './station.component.html',
  styleUrls: ['./station.component.css']
})
export class StationComponent {

  stationsData!: any;
  clientData: clientDataType [] = [];
  hostData: any = [];
  sensorsData: any = [];
  formStation!: FormGroup;
  stationModel :StationModel = new StationModel();
  clientIdsToBeAdded: string[] = [];
  showAddButton!: boolean;
  showUpdateButton!: boolean;
  detailsModal : any = {
    title: '',
    body: {},
  }

  constructor(private api: ApiService, private fb: FormBuilder) {
    this.getAllStations();
    this.getAllClients();
    this.getAllHosts();
    this.getAllSensors();
    this.formStation = fb.group({
      name: [''],
      diary: [''],
      host: [''],
      clients: [''],
      mac: [''],
      longitude: [''],
      latitude: [''],
      altitude: [''],
    });
  }

  getAllStations() {
    this.api.get('http://localhost:8080/api/v1/station/all')
      .subscribe(res => {
        this.stationsData = res;
      });
  }

  Date(ISODate: any) {
    return new Date(ISODate).toLocaleString();
  }

  getAllClients() {
    this.api.get('http://localhost:8080/api/v1/client/all')
      .subscribe(res => {
        res.forEach((client: any) => {
          this.clientData.push({
            clientData: client,
            isAddedToStation: false
          });
        });
      });
  }

  getAllHosts() {
    this.api.get('http://localhost:8080/api/v1/host/all')
      .subscribe(res => {
        this.hostData = res;
      });
  }

  getHostName(hostId: any) {
    return this.hostData?.find((host: { id: any; }) => host.id === hostId)?.name;
  }

  getClientName(clientId: any) {
    return this.clientData?.find((client: { clientData: { id: any; }; }) =>
      client.clientData.id === clientId)?.clientData.name;
  }

  onAddClientToConfig(client: clientDataType) {
    client.isAddedToStation = true;
    this.clientIdsToBeAdded.push(client.clientData.id);
  }

  onRemoveClientToConfig(client: clientDataType) {
    client.isAddedToStation = false;
    this.clientIdsToBeAdded = this.clientIdsToBeAdded.filter((id: string) => id !== client.clientData.id);
  }

  onOpenEditClient(row: any) {
    this.showAddButton = false;
    this.showUpdateButton = true;
  }

  onOpenAddClient() {
    this.showAddButton = true;
    this.showUpdateButton = false;
  }

  onAddStation() {
    this.stationModel.name = this.formStation.value.name;
    this.stationModel.diary = this.formStation.value.diary;
    this.stationModel.host = this.formStation.value.host;
    this.stationModel.clients = this.clientIdsToBeAdded;
    this.stationModel.location.longitude = this.formStation.value.longitude;
    this.stationModel.location.latitude = this.formStation.value.latitude;
    this.stationModel.location.altitude = this.formStation.value.altitude;

    this.api.post('http://localhost:8080/api/v1/station/add', this.stationModel)
      .subscribe(res => {
        this.getAllStations();
        this.formStation.reset();
        alert('Station added successfully');
        document.getElementById('cancel-btn')?.click();
      });
  }

  onUpdateStation() {

  }

  getAllSensors() {
    this.api.get('http://localhost:8080/api/v1/sensor/all')
      .subscribe(res => {
        this.sensorsData = res;
      });
  }

  getSensorName(sensorId: any) {
    return this.sensorsData?.find((sensor: { id: any; }) => sensor.id === sensorId)?.name;
  }

  onDetailsModal(type:string, data: any) {

    let sensors: any = [];
    if (type === 'client') {
      const sensorId: string[] = this.clientData?.find((client: { clientData: { id: any; }; }) =>
          client.clientData.id === data)?.clientData.sensors;
      sensorId.forEach((id: string) => {
        sensors.push(this.getSensorName(id));
      });
    }

    if (type === 'host') {
      this.detailsModal.title = 'Host Details';
      this.detailsModal.body = {
        name: this.hostData?.find((host: { id: any; }) => host.id === data)?.name,
        mac: this.hostData?.find((host: { id: any; }) => host.id === data)?.mac,
        simId: this.hostData?.find((host: { id: any; }) => host.id === data)?.simId,
      };
    } else if (type === 'client') {
      this.detailsModal.title = 'Client Details';
      this.detailsModal.body = {
        name: this.clientData?.find((client: { clientData: { id: any; }; }) =>
          client.clientData.id === data)?.clientData.name,
        mac: this.clientData?.find((client: { clientData: { id: any; }; }) =>
          client.clientData.id === data)?.clientData.mac,
        connectionType: this.clientData?.find((client: { clientData: { id: any; }; }) =>
          client.clientData.id === data)?.clientData.connectionType,
        sensors: sensors,
      };
    }
  }
}
