import {Component, OnInit} from '@angular/core';
import {FormBuilder, FormGroup} from "@angular/forms";
import {UserModel} from "./user.model";
import {ApiService} from "../../../../shared/api.service";
import {Router} from "@angular/router";

@Component({
  selector: 'app-userManagment',
  templateUrl: './userManagement.component.html',
  styleUrls: ['./userManagement.component.css']
})
export class UserManagementComponent implements OnInit {
  form!: FormGroup;
  user: UserModel = new UserModel();

  userData!: any;

  showAddButton!: boolean;
  showUpdateButton!: boolean;

  constructor(private fb: FormBuilder, private api: ApiService, private router: Router) {
    this.form = this.fb.group({
      username: [''],
      email: [''],
      role: [''],
      password: ['']
    });
    this.form.controls['role'].setValue('none', {onlySelf: true});
  }

  onAddUser() {
    this.form.reset();
    this.form.controls['role'].setValue('none', {onlySelf: true});
    this.showAddButton = true;
    this.showUpdateButton = false;
  }

  onSubmit() {
    this.user.username = this.form.value.username;
    this.user.email = this.form.value.email;
    this.user.password = this.form.value.password;
    this.user.roles = [this.form.value.role];
    this.api.post('http://localhost:8080/api/v1/auth/signup', this.user)
      .subscribe(res => {
        console.log(res);
        this.form.reset();
        const cancelButton = document.getElementById('cancel-btn');
        // @ts-ignore
        cancelButton.click();
        this.getAllUsers();
        alert('User created successfully.');
      }, err => {
        alert('An error has occurred.');
      });
  }

  getAllUsers() {
    this.api.get('http://localhost:8080/api/v1/auth/users')
      .subscribe(res => {
        this.userData = res;
      });
  }

  deleteUser(id: string) {
    this.api.delete('http://localhost:8080/api/v1/auth/user/delete', id)
      .subscribe(res => {
          this.getAllUsers();
          alert('User deleted successfully.');
        },
        err => {
          alert('An error has occurred.');
        });
  }

  onEdit(row: any) {
    this.form.patchValue({
      username: row.username,
      email: row.email
    });
    this.form.controls['role'].setValue(row.roles[0].substring(5).toLowerCase(), {onlySelf: true});
    this.user.id = row.id;
    this.showAddButton = false;
    this.showUpdateButton = true;
  }

  ngOnInit(): void {
    this.getAllUsers();
    this.form.value.role = 'none';
  }

  // TODO: Add a method to remove duplicates
  updateUser() {
    this.user.username = this.form.value.username;
    this.user.email = this.form.value.email;
    this.user.password = this.form.value.password;
    this.user.roles = [this.form.value.role];
    this.api.put('http://localhost:8080/api/v1/auth/user/update', this.user.id, this.user)
      .subscribe(res => {
        console.log(res);
        this.form.reset();
        const cancelButton = document.getElementById('cancel-btn');
        // @ts-ignore
        cancelButton.click();
        this.getAllUsers();
        alert('User updated successfully.');
      }, err => {
        alert('An error has occurred.');
      });
  }

  logout() {
    localStorage.removeItem('token');
    localStorage.removeItem('role');
    this.router.navigate(['/login']);
  }
}
