import {Component,  OnInit} from '@angular/core';
import {MatTreeFlatDataSource, MatTreeFlattener} from '@angular/material/tree';
import {FlatTreeControl} from "@angular/cdk/tree";
import {
  Client,
  ClientControllerService,
  Host,
  HostControllerService, SensorControllerService, Station,
  StationControllerService
} from "../../../../../../projects/generated-api/src";
import {combineLatest,  Observable, of, switchMap, tap} from "rxjs";



/**
 * Food data with nested structure.
 * Each node has a name and an optional list of children.
 */


let x:string=""

interface TreeNode {
  name: string;

  children?: TreeNode[];
}

enum NodeType {
  Station = 'Station',
  Host = 'Host',
  Client = 'Client',
  Sensor = 'Sensor',
}

interface DateTreeNode extends TreeNode{
  name: string;
  type: NodeType;
  children?: DateTreeNode[];
}


let TREE_DATA1:DateTreeNode[]=[]

const TREE_DATA: TreeNode[] = [
  {
    name: 'Fruitss',
    children: [{name: 'Apple'}, {name: 'Banana'}, {name: 'Fruit loops'}],
  },
  {
    name: 'Vegetables',
    children: [
      {
        name: 'Green',
        children: [
          {
            name: 'Fruit',
            children: [{name: 'Apple'}, {name: 'Banana'}, {name: 'Fruit loops'}],
          }
          , {name: 'Brussels sprouts'}],
      },
      {
        name: 'Orange',
        children: [{name: 'Pumpkins'}, {name: 'Carrots'}],
      },
    ],
  },
];

export class TreeStation {
  private station?:Station={name:'Test '}
  tree_Data: TreeNode={
    name:  "UNDEFINED",
    children: [],
  };

  addStation(station:Station)
  {
    this.station=station;
  }

  getStation():Station{
    console.log('getstaion',this.station)
    //@ts-ignore
    return this.station
  }

  addHost(host: Host) {
    this.tree_Data.children?.push({
      name: host.name ? host.name : "UNDEFINED",
      children: [],
    })
  }

  addClient(client: Client) {
    if(this.tree_Data.children?.length==0){
      throw new Error("No Hosts available");
    }
    this.tree_Data.children?.push({
      name: client.name ? client.name : "UNDEFINED",
      children: [],
    })
  }
}

/** Flat node with expandable and level information */
interface ExampleFlatNode {
  expandable: boolean;
  name: string;
  type?: string;
  level: number;
}
@Component({
  selector: 'app-station-config',
  templateUrl: './station-config.component.html',
  styleUrls: ['./station-config.component.css']
})
export class StationConfigComponent  implements OnInit{

  public state:boolean=false
  public dataSate=false;
  public treeStation?:DateTreeNode
  private _transformer = (node: DateTreeNode, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
    };
  };
  hasChild = (_: number, node: ExampleFlatNode) => node.expandable;

  treeControl = new FlatTreeControl<ExampleFlatNode>(
    node => node.level,
    node => node.expandable,
  );

  treeFlattener = new MatTreeFlattener(
    this._transformer,
    node => node.level,
    node => node.expandable,
    node => node.children,
  );

  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);

  constructor(
    public stationController: StationControllerService,
    private hostController: HostControllerService,
    private clientController: ClientControllerService,
    private sensorController: SensorControllerService,
  ) {

    this.dataSource.data = TREE_DATA1;

  }


  ngOnInit(): void {
   // this.fetchData();
    TREE_DATA1=[]
    this.fetchData();
  }

  fetchData(){
    let returnNode=(name:string,type:NodeType,childs:DateTreeNode[]):DateTreeNode=> {return {
      name: name ? name : 'UNDEFINED',
      type: type,
      children:childs,
    }};
    let returnMultipleNodes=(names:string[],type:NodeType):DateTreeNode[]=> {
      return names.map(name=>returnNode(name,type,[]))
    }

    let returnNodeWithMultiChild=(p_name:string,p_type:NodeType,c_names:string[],c_type:NodeType):DateTreeNode=> {return {
      name: p_name ? p_name : 'UNDEFINED',
      type: p_type,
      children: returnMultipleNodes(c_names,c_type),
    }};


    let saveClients3=(client_names:string[],treeNode:DateTreeNode[]):Observable<Client[]>=>{
      let clients:Observable<Client>[]= client_names.map(name=> this.clientController.getClientById(name))
      return combineLatest(clients).pipe(
        tap(clients=>{
          clients.forEach(client=>treeNode.push(returnNodeWithMultiChild(client.name??"",NodeType.Client,client.sensors??[],NodeType.Sensor)))
        })
      )
    }

      let clientsDataTree: DateTreeNode[] = []
      let station:Station={}
    // Step 1: Call getById function
      this.stationController.getById("ibk_s_id").pipe(
        tap(s => station = s),
        switchMap(() => {
          // Step 2: Call saveClients function
          return saveClients3(station.clients ?? [], clientsDataTree);
        }),
      ).subscribe(() => {

        // Handle the final result of stationNodes
        let dateTreeNode: DateTreeNode = returnNode(station.name ?? "", NodeType.Station, clientsDataTree);
        this.treeStation=dateTreeNode;
        TREE_DATA1.push(dateTreeNode)
        this.dataSource.data=TREE_DATA1
        this.dataSate=true;
        console.log('final result:', dateTreeNode);
        console.log("tree data1",TREE_DATA1)
      });
  }

  alert=()=>{alert("focused")}

}


