import { Component } from '@angular/core';
import {
  AvgMinMax,
  DendrometerDailyValue,
  LevelOneResponse, StationControllerService,
  SumOrAvg
} from "../../../../../../projects/generated-api/src";
import {FormControl} from "@angular/forms";
import {DatePipe} from "@angular/common";
import {ApiService} from "../../../../shared/api.service";



@Component({
  selector: 'app-summary',
  templateUrl: './summary.component.html',
  styleUrls: ['./summary.component.css']
})
export class SummaryComponent {

  isGrid:boolean=true

  //Input Controls
  dateControl = new FormControl(new Date());
  stationControl = new FormControl();
  availableStation: string[] = [''];

  //Data Objects to Store API Responses
  levelOne!:LevelOneResponse
  avgMinMax:AvgMinMax[]=[]
  sumOrAvg:SumOrAvg[]=[]
  dentrometerDailyValue:DendrometerDailyValue[]=[]


  constructor(private api:ApiService,
              private stationControllerService: StationControllerService) {}

  ngOnInit(){
    this.dateControl.valueChanges.subscribe(date => {this.reload()});

    //get all station from server
    this.stationControllerService.getAll().subscribe(x => {
      console.log('available station', x);
      this.availableStation=x.map(x=>x.id!==undefined ?x.id:"No station avalable")
    });
    //subscribe to station control
    this.stationControl.valueChanges.subscribe(x=>{
      console.log(x)
      this.reload()
    })
  }


  reload() {
    console.log(this.dateControl.value)
    let datePipe = new DatePipe('en-US');
    let dateStart = datePipe.transform(this.dateControl.value, 'dd-MM-yyyy');
    console.log(dateStart)
    let stationId = this.stationControl.value;
    this.api.get("http://localhost:8080/api/v1/server/get/lvl1/"+stationId+"?date="+dateStart).subscribe(
      res=>{

        this.levelOne=res
        console.log(res)
        // @ts-ignore
        this.avgMinMax=this.levelOne.avgMinMax
        // @ts-ignore
        this.sumOrAvg=this.levelOne.sumOrAvg
        // @ts-ignore
        this.dentrometerDailyValue=this.levelOne.dendrometerDailyValues
      }
    )
  }

}
